#ifndef NT2_INCLUDE_FUNCTIONS_BRENT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_BRENT_HPP_INCLUDED

#include <nt2/optimization/include/functions/brent.hpp>

#endif
